@@ -1,33 +1,33 @@
 ImportFileButton <- function(label="Import", container,...)
 {
-  ImpFilB <- gbutton(label, contain=container, handler=function(h,...){
+  ImpFilB <- gbutton(label, container=container, handler=function(h,...){
       path <- gfile(type="open",filter=list("text files" = list(mime.types = c("text/plain")),
               "All files" = list(patterns = c("*"))))
       if (path!=""){
         Encoding(path) <- "UTF-8" ## have to convert, otherwise, can not find the file.
-        ImportFile(path,con=.rqda$qdacon)
+        ImportFile(path,container=.rqda$qdacon)
          FileNamesUpdate()
       }
     }
           )
-  assign("ImpFilB",ImpFilB,env=button)
+  assign("ImpFilB",ImpFilB,envir=button)
   gtkWidgetSetSensitive(button$ImpFilB@widget@widget,FALSE)
 }
 
 NewFileButton <- function(label="New", container,...)
 {
-    NewFilB <- gbutton(label, contain=container, handler=function(h,...){
-        if (is_projOpen(env = .rqda, conName = "qdacon", message = FALSE)) {
+    NewFilB <- gbutton(label, container=container, handler=function(h,...){
+        if (is_projOpen(envir = .rqda, conName = "qdacon", message = FALSE)) {
             AddNewFileFun()
         }
     }
                        )
-    assign("NewFilB",NewFilB,env=button)
+    assign("NewFilB",NewFilB,envir=button)
     enabled(NewFilB) <- FALSE
 }
 
 DeleteFileButton <- function(label="Delete", container,...){
-  DelFilB <- gbutton(label,contain=container,handler=function(h,...){
+  DelFilB <- gbutton(label,container=container,handler=function(h,...){
               SelectedFile <- svalue(.rqda$.fnames_rqda)
               Encoding(SelectedFile) <- "UTF-8"
               ## if the project open and a file is selected, then continue the action
@@ -51,41 +51,41 @@ DeleteFileButton <- function(label="Delete", container,...){
                   UpdateWidget(".fnames_rqda",from=SelectedFile,to=NULL)
               }
           },
-          action=list(env=.rqda,conName="qdacon")
+          action=list(envir=.rqda,conName="qdacon")
           )
-  assign("DelFilB",DelFilB,env=button)
+  assign("DelFilB",DelFilB,envir=button)
   gtkWidgetSetSensitive(button$DelFilB@widget@widget,FALSE)
 }
 
 ViewFileButton <-  function(label="Open", container,...)
 {
-  VieFilB <- gbutton(label,contain=container,h=function(h,...)
+  VieFilB <- gbutton(label,container=container,handler=function(h,...)
           {
             ViewFileFun(FileNameWidget=.rqda$.fnames_rqda)
           }
           )
-  assign("VieFilB",VieFilB,env=button)
+  assign("VieFilB",VieFilB,envir=button)
   gtkWidgetSetSensitive(button$VieFilB@widget@widget,FALSE)
 }
 
 
 File_MemoButton <- function(label="Memo", container=.rqda$.files_button,FileWidget=.rqda$.fnames_rqda,...){
   ## memo of selected file.
-  FilMemB <- gbutton(label, contain=container, handler=function(h,...) {
+  FilMemB <- gbutton(label, container=container, handler=function(h,...) {
       MemoWidget("File",FileWidget,"source")
   }
           )
-  assign("FilMemB",FilMemB,env=button)
+  assign("FilMemB",FilMemB,envir=button)
   gtkWidgetSetSensitive(button$FilMemB@widget@widget,FALSE)
 }
 
 File_RenameButton <- function(label="Rename", container=.rqda$.files_button,FileWidget=.rqda$.fnames_rqda,...)
 {
   ## rename of selected file.
-  FilRenB <- gbutton(label, contain=container, handler=function(h,...) {
+  FilRenB <- gbutton(label, container=container, handler=function(h,...) {
       selectedFN <- svalue(FileWidget)
       if (length(selectedFN)==0){
-        gmessage("Select a file first.",icon="error",con=TRUE)
+        gmessage("Select a file first.",icon="error",container=TRUE)
       }
       else {
         ## get the new file names
@@ -104,14 +104,14 @@ File_RenameButton <- function(label="Rename", container=.rqda$.files_button,File
     }
           )
   FilRenB
-  assign("FilRenB",FilRenB,env=button)
+  assign("FilRenB",FilRenB,envir=button)
   gtkWidgetSetSensitive(button$FilRenB@widget@widget,FALSE)
 }
 
 FileAttribute_Button <- function(label="Attribute",container=.rqda$.files_button,FileWidget=.rqda$.fnames_rqda,...)
 {
-    FileAttrB <- gbutton(label, contain=container, handler=function(h,...) {
-        if (is_projOpen(env=.rqda,conName="qdacon")) {
+    FileAttrB <- gbutton(label, container=container, handler=function(h,...) {
+        if (is_projOpen(envir=.rqda,conName="qdacon")) {
             Selected <- svalue(FileWidget)
             if (length(Selected !=0 )){
                 fileId <- RQDAQuery(sprintf("select id from source where status=1 and name='%s'",
@@ -122,13 +122,13 @@ FileAttribute_Button <- function(label="Attribute",container=.rqda$.files_button
     }
                          )
     FileAttrB
-    assign("FileAttrB",FileAttrB,env=button)
+    assign("FileAttrB",FileAttrB,envir=button)
     enabled(FileAttrB) <- FALSE
 }
 
 AddNewFileFun <- function(){
-  if (is_projOpen(env=.rqda,"qdacon")) {
-    if (exists(".AddNewFileWidget",env=.rqda) && isExtant(.rqda$.AddNewFileWidget)) {
+  if (is_projOpen(envir=.rqda,"qdacon")) {
+    if (exists(".AddNewFileWidget",envir=.rqda) && isExtant(.rqda$.AddNewFileWidget)) {
       dispose(.rqda$.AddNewFileWidget)
     } ## close the widget if open
     gw <- gwindow(title="Add a new file", parent=getOption("widgetCoordinate"),
@@ -136,8 +136,8 @@ AddNewFileFun <- function(){
                   height = getOption("widgetSize")[2])
     mainIcon <- system.file("icon", "mainIcon.png", package = "RQDA")
     gw@widget@widget$SetIconFromFile(mainIcon)
-    assign(".AddNewFileWidget",gw,env=.rqda)
-    assign(".AddNewFileWidget2",gpanedgroup(horizontal = FALSE, con=get(".AddNewFileWidget",env=.rqda)),env=.rqda)
+    assign(".AddNewFileWidget",gw,envir=.rqda)
+    assign(".AddNewFileWidget2",gpanedgroup(horizontal = FALSE, container=get(".AddNewFileWidget",envir=.rqda)),envir=.rqda)
     saveFileFun <- function() {
       ## require a title for the file
       Ftitle <- ginput("Enter the title", icon="info")
@@ -165,24 +165,24 @@ AddNewFileFun <- function(){
     }
   } ## end of saveFileFun
 
-    gl <- glayout(homogeneous=T,con=get(".AddNewFileWidget2",env=.rqda))
+    gl <- glayout(homogeneous=T,container=get(".AddNewFileWidget2",envir=.rqda))
     AddNewFilB <- gbutton("Save To Project", handler=function(h,...){saveFileFun()})
     enabled(AddNewFilB) <- FALSE
-    assign("AddNewFilB",AddNewFilB,env=button)
+    assign("AddNewFilB",AddNewFilB,envir=button)
     AddNewFilB2 <- gbutton("Save and close", handler=function(h,...){
         suc <- saveFileFun()
         if (suc) dispose(.rqda$.AddNewFileWidget)
     }
                            )
     enabled(AddNewFilB2) <- FALSE
-    assign("AddNewFilB2",AddNewFilB2,env=button)
+    assign("AddNewFilB2",AddNewFilB2,envir=button)
     gl[1,1] <- AddNewFilB
     gl[1,2] <- AddNewFilB2
-    tmp <- gtext(container=get(".AddNewFileWidget2",env=.rqda))
+    tmp <- gtext(container=get(".AddNewFileWidget2",envir=.rqda))
     font <- pangoFontDescriptionFromString(.rqda$font)
     gtkWidgetModifyFont(tmp@widget@widget,font) ## set the default fontsize
-    assign(".AddNewFileWidgetW",tmp,env=.rqda)
-    textW <- get(".AddNewFileWidgetW",env=.rqda)
+    assign(".AddNewFileWidgetW",tmp,envir=.rqda)
+    textW <- get(".AddNewFileWidgetW",envir=.rqda)
     addHandlerKeystroke(.rqda$.AddNewFileWidgetW,handler=function(h,...){
       enabled(button$AddNewFilB) <- TRUE
       enabled(button$AddNewFilB2) <- TRUE
@@ -200,24 +200,24 @@ AddNewFileFun <- function(){
 ## pop-up menu of add to case and F-cat from Files Tab
 FileNamesWidgetMenu <- list()
 FileNamesWidgetMenu$"Add New File ..."$handler <- function(h, ...) {
-  if (is_projOpen(env = .rqda, conName = "qdacon", message = FALSE)) {
+  if (is_projOpen(envir = .rqda, conName = "qdacon", message = FALSE)) {
     AddNewFileFun()
   }
 }
 FileNamesWidgetMenu$"Add To Case ..."$handler <- function(h, ...) {
-    if (is_projOpen(env = .rqda, conName = "qdacon", message = FALSE)) {
+    if (is_projOpen(envir = .rqda, conName = "qdacon", message = FALSE)) {
       AddFileToCaselinkage()
       UpdateFileofCaseWidget()
     }
   }
 FileNamesWidgetMenu$"Add To File Category ..."$handler <- function(h, ...) {
-    if (is_projOpen(env = .rqda, conName = "qdacon", message = FALSE)) {
+    if (is_projOpen(envir = .rqda, conName = "qdacon", message = FALSE)) {
       AddToFileCategory()
       UpdateFileofCatWidget()
     }
   }
 FileNamesWidgetMenu$"Add/modify Attributes of The Open File..."$handler <- function(h,...){
-  if (is_projOpen(env=.rqda,conName="qdacon")) {
+  if (is_projOpen(envir=.rqda,conName="qdacon")) {
     Selected <- tryCatch(svalue(RQDA:::.rqda$.root_edit),error=function(e){NULL})
     if (!is.null(Selected)){
       fileId <- RQDAQuery(sprintf("select id from source where status=1 and name='%s'",
@@ -226,12 +226,12 @@ FileNamesWidgetMenu$"Add/modify Attributes of The Open File..."$handler <- funct
   }
 }}
 FileNamesWidgetMenu$"View Attributes"$handler <- function(h,...){
-  if (is_projOpen(env=.rqda,conName="qdacon")) {
+  if (is_projOpen(envir=.rqda,conName="qdacon")) {
    viewFileAttr()
   }
 }
 FileNamesWidgetMenu$"Export File Attributes"$handler <- function(h,...){
-    if (is_projOpen(env=.rqda,conName="qdacon")) {
+    if (is_projOpen(envir=.rqda,conName="qdacon")) {
         fName <- gfile(type='save',filter=list("csv"=list(pattern=c("*.csv"))))
         Encoding(fName) <- "UTF-8"
         if (length(grep(".csv$",fName))==0) fName <- sprintf("%s.csv",fName)
@@ -242,19 +242,15 @@ FileNamesWidgetMenu$"Edit Seleted File"$handler <- function(h, ...) {
   EditFileFun()
 }
 FileNamesWidgetMenu$"Export Coded file as HTML"$handler <- function(h, ...) {
-    if (is_projOpen(env = .rqda, conName = "qdacon", message = FALSE)) {
+    if (is_projOpen(envir = .rqda, conName = "qdacon", message = FALSE)) {
         path=gfile(type="save",text = "Type a name for the exported codings and click OK.")
         if (!is.na(path)){
             Encoding(path) <- "UTF-8"
             path <- sprintf("%s.html",path)
             exportCodedFile(file=path,getFileIds(type="selected")[1])
         }}}
-FileNamesWidgetMenu$"Find a word..."$handler <- function(h, ...) {
-    if (exists(".openfile_gui",env=.rqda) && isExtant(.rqda$.openfile_gui)) {
-        SearchButton(RQDA:::.rqda$.openfile_gui)
-    }
-}
-## a=gtext("this is a test for search a.",con=T)
+
+## a=gtext("this is a test for search a.",container=T)
 ## b<-a@widget@widget$GetBuffer()
 ## b$GetIterAtOffset(0)
 ## i0=b$GetIterAtOffset(0)
@@ -262,34 +258,50 @@ FileNamesWidgetMenu$"Find a word..."$handler <- function(h, ...) {
 ## s0$match.start$GetOffset()
 ## s0$match.end$GetOffset()
 
+FileNamesWidgetMenu$"File Annotations"$handler <- function(h,...){
+ if (is_projOpen(envir=.rqda,conName="qdacon")) {
+ print(getAnnos())
+}}
 FileNamesWidgetMenu$"File Memo"$handler <- function(h,...){
- if (is_projOpen(env=.rqda,conName="qdacon")) {
+ if (is_projOpen(envir=.rqda,conName="qdacon")) {
  MemoWidget("File",.rqda$.fnames_rqda,"source")
 ## see CodeCatButton.R  for definition of MemoWidget
 }
 }
+FileNamesWidgetMenu$"Import PDF Highligts via rjpod (selector)"$handler <- function(h,...){
+    importPDFHL(engine="rjpod")
+}
+FileNamesWidgetMenu$"Import PDF Highligts via rjpod (file path)"$handler <- function(h,...){
+    fpath=ginput("Enter a pdf file path",con=T)
+    importPDFHL(file=fpath, engine="rjpod")
+}
 FileNamesWidgetMenu$"Open Selected File"$handler <- function(h,...){
   ViewFileFun(FileNameWidget=.rqda$.fnames_rqda)
 }
 FileNamesWidgetMenu$"Open Previous Coded File"$handler <- function(h,...){
-  if (is_projOpen(env = .rqda, conName = "qdacon", message = FALSE)) {
+  if (is_projOpen(envir = .rqda, conName = "qdacon", message = FALSE)) {
     fname <- RQDAQuery("select name from source where id in ( select fid from coding where rowid in (select max(rowid) from coding where status=1))")$name
     if (length(fname)!=0)  fname <- enc(fname,"UTF-8")
     ViewFileFunHelper(FileName=fname)
   }}
-FileNamesWidgetMenu$"Search Files..."$handler <- function(h, ...) {
-    if (is_projOpen(env = .rqda, conName = "qdacon", message = FALSE)) {
+FileNamesWidgetMenu$"Search for a Word"$handler <- function(h, ...) {
+    if (exists(".openfile_gui",envir=.rqda) && isExtant(.rqda$.openfile_gui)) {
+        SearchButton(RQDA:::.rqda$.openfile_gui)
+    }
+}
+FileNamesWidgetMenu$"Search all files ..."$handler <- function(h, ...) {
+    if (is_projOpen(envir = .rqda, conName = "qdacon", message = FALSE)) {
     pattern <- ifelse(is.null(.rqda$lastsearch),"file like '%%'",.rqda$lastsearch)
     pattern <- ginput("Please input a search pattern.",text=pattern)
     if (!is.na(pattern)){
-    tryCatch(SearchFiles(pattern,Widget=".fnames_rqda",is.UTF8=TRUE),error=function(e) gmessage("Error~~~."),con=TRUE)
+    tryCatch(SearchFiles(pattern,Widget=".fnames_rqda",is.UTF8=TRUE),error=function(e) gmessage("Error~~~."),container=TRUE)
     Encoding(pattern) <- "UTF-8"
-    assign("lastsearch",pattern,env=.rqda)
+    assign("lastsearch",pattern,envir=.rqda)
     }
     }
   }
 FileNamesWidgetMenu$"Show ..."$"Show All Sorted By Imported Time"$handler <- function(h, ...) {
-    if (is_projOpen(env = .rqda, conName = "qdacon", message = FALSE)) {
+    if (is_projOpen(envir = .rqda, conName = "qdacon", message = FALSE)) {
      ##FileNamesUpdate(FileNamesWidget=.rqda$.fnames_rqda)
      FileNameWidgetUpdate(FileNamesWidget=.rqda$.fnames_rqda,FileId=GetFileId(condition="unconditional",type="all"))
     }
@@ -300,7 +312,7 @@ FileNamesWidgetMenu$"Show ..."$"Show Coded Files Sorted by Imported time"$handle
   }
 }
 FileNamesWidgetMenu$"Show ..."$"Show Uncoded Files Sorted by Imported time"$handler <- function(h, ...) {
-    if (is_projOpen(env = .rqda, conName = "qdacon", message = FALSE)) {
+    if (is_projOpen(envir = .rqda, conName = "qdacon", message = FALSE)) {
       ## UncodedFileNamesUpdate(FileNamesWidget = .rqda$.fnames_rqda)
       FileNameWidgetUpdate(FileNamesWidget=.rqda$.fnames_rqda,FileId=GetFileId(condition="unconditional",type="uncoded"))
       ## By default, the file names in the widget will be sorted.
@@ -310,42 +322,53 @@ FileNamesWidgetMenu$"Show ..."$"Show Files With Annotation"$handler <- function(
   fileid <- RQDAQuery("select fid from annotation where status=1 group by fid")$fid
   if (length(fileid)!=0) {
     FileNameWidgetUpdate(FileNamesWidget=.rqda$.fnames_rqda,FileId=fileid)
-  } else gmessage("No file with memo.",con=TRUE)
+  } else gmessage("No file with memo.",container=TRUE)
 }
-FileNamesWidgetMenu$"Show ..."$"Show Files With Memo"$handler <- function(h, ...) {
-    if (is_projOpen(env = .rqda, conName = "qdacon", message = FALSE)) {
-    fileid <- dbGetQuery(.rqda$qdacon,"select id from source where memo is not null")
-    if (nrow(fileid)!=0) {
-    fileid <- fileid[[1]]
-    FileNameWidgetUpdate(FileNamesWidget=.rqda$.fnames_rqda,FileId=fileid)
-    } else gmessage("No file with memo.",con=TRUE)
-    }
-  }
 FileNamesWidgetMenu$"Show ..."$"Show Files Without Annotation"$handler <- function(h, ...) {
   fileid <- RQDAQuery("select id from source where status=1 and id not in (select fid from annotation where status=1 group by fid)")$id
   if (length(fileid)!=0) {
     FileNameWidgetUpdate(FileNamesWidget=.rqda$.fnames_rqda,FileId=fileid)
-  } else gmessage("All files have annotation.",con=TRUE)
+  } else gmessage("All files have annotation.",container=TRUE)
 }
+
+FileNamesWidgetMenu$"Show ..."$"Show Files With Memo"$handler <- function(h, ...) {
+    if (is_projOpen(envir = .rqda, conName = "qdacon", message = FALSE)) {
+    fileid <- dbGetQuery(.rqda$qdacon,"select id from source where memo is not null")
+    if (nrow(fileid)!=0) {
+    fileid <- fileid[[1]]
+    FileNameWidgetUpdate(FileNamesWidget=.rqda$.fnames_rqda,FileId=fileid)
+    } else gmessage("No file with memo.",container=TRUE)
+    }
+  }
 FileNamesWidgetMenu$"Show ..."$"Show Files Without Memo"$handler <- function(h, ...) {
-    if (is_projOpen(env = .rqda, conName = "qdacon", message = FALSE)) {
+    if (is_projOpen(envir = .rqda, conName = "qdacon", message = FALSE)) {
     fileid <- dbGetQuery(.rqda$qdacon,"select id from source where memo is null")
     if (nrow(fileid)!=0) {
     fileid <- fileid[[1]]
     FileNameWidgetUpdate(FileNamesWidget=.rqda$.fnames_rqda,FileId=fileid)
-    } else gmessage("No file is found.",con=TRUE)
+    } else gmessage("No file is found.",container=TRUE)
     }
   }
+
 FileNamesWidgetMenu$"Show ..."$"Show Files Without File Category"$handler <- function(h, ...) {
-    if (is_projOpen(env = .rqda, conName = "qdacon", message = FALSE)) {
+    if (is_projOpen(envir = .rqda, conName = "qdacon", message = FALSE)) {
         fileid <- RQDAQuery("select id from source where status=1 and id not in (select fid from treefile where status=1)")
         if (nrow(fileid)!=0) {
             fileid <- fileid[[1]]
             FileNameWidgetUpdate(FileNamesWidget=.rqda$.fnames_rqda,FileId=fileid)
-        } else gmessage("All are linked with file category.",con=TRUE)
+        } else gmessage("All are linked with file category.",container=TRUE)
+    }
+}
+FileNamesWidgetMenu$"Show ..."$"Show Files With No Case"$handler <- function(h, ...) {
+    if (is_projOpen(envir = .rqda, conName = "qdacon", message = FALSE)) {
+        fileid <- RQDAQuery("select id from source where status=1 and id not in (select fid from caselinkage where status=1)")
+        if (nrow(fileid)!=0) {
+            fileid <- fileid[[1]]
+            FileNameWidgetUpdate(FileNamesWidget=.rqda$.fnames_rqda,FileId=fileid)
+        } else gmessage("All are linked with cases.",container=TRUE)
     }
 }
 FileNamesWidgetMenu$"Show Selected File Property"$handler <- function(h, ...) {
-  if (is_projOpen(env = .rqda, conName = "qdacon", message = FALSE)) {
+  if (is_projOpen(envir = .rqda, conName = "qdacon", message = FALSE)) {
   ShowFileProperty()
 }}
