@@ -3,7 +3,7 @@ AddJournalButton <- function(label="ADD"){
         AddNewJournalFun()
     }
           )
-  assign("AddJouB",AddJouB,env=button)
+  assign("AddJouB",AddJouB,envir=button)
   enabled(AddJouB) <- FALSE
   AddJouB
 }
@@ -19,7 +19,7 @@ DeleteJournalButton <- function(label="Delete"){
         }
       }
           )
-  assign("DelJouB",DelJouB,env=button)
+  assign("DelJouB",DelJouB,envir=button)
   enabled(DelJouB) <- FALSE
   DelJouB
 }
@@ -28,14 +28,15 @@ RenameJournalButton <- function(label="Rename")
 {
   RenJouB <- gbutton(label,handler=function(h,...) {
       selected <- svalue(.rqda$.JournalNamesWidget)
-        NewName <- ginput("Enter new journal name. ",text=selected, icon="info")
+      NewName <- ginput("Enter new journal name. ",text=selected, icon="info")
+      Encoding(NewName) <- "UTF-8"
         if (!is.na(NewName)) {
           rename(from=selected,to=NewName,"journal")
           JournalNamesUpdate()
         }
     }
           )
-  assign("RenJouB",RenJouB,env=button)
+  assign("RenJouB",RenJouB,envir=button)
   enabled(RenJouB) <- FALSE
   RenJouB
 }
@@ -46,7 +47,7 @@ OpenJournalButton <- function(label="Open")
   OpeJouB <- gbutton(label,handler=function(h,...) {
       ViewJournalWidget()
   })
-  assign("OpeJouB",OpeJouB,env=button)
+  assign("OpeJouB",OpeJouB,envir=button)
   enabled(OpeJouB) <- FALSE
   OpeJouB
 }
@@ -59,6 +60,7 @@ JournalNamesUpdate <- function(Widget=.rqda$.JournalNamesWidget,decreasing=FALSE
       journal <- NULL
     } else {
       journal <- journal[,1]
+      Encoding(journal) <- "UTF-8"
       journal <- journal[OrderByTime(substring(journal,0,20),decreasing=decreasing)]
     }
     tryCatch(Widget[] <- journal, error=function(e){})
@@ -66,16 +68,16 @@ JournalNamesUpdate <- function(Widget=.rqda$.JournalNamesWidget,decreasing=FALSE
 }
 
 AddNewJournalFun <- function(){
-    if (is_projOpen(env=.rqda,"qdacon")) {
+    if (is_projOpen(envir=.rqda,"qdacon")) {
         tryCatch(eval(parse(text="dispose(.rqda$.AddNewJournalWidget")),error=function(e) {}) ## close the widget if open
         gw <- gwindow(title="Add New Journal.",parent=getOption("widgetCoordinate"),
                       width = getOption("widgetSize")[1], height = getOption("widgetSize")[2]
                            )
         mainIcon <- system.file("icon", "mainIcon.png", package = "RQDA")
         gw@widget@widget$SetIconFromFile(mainIcon)
-        assign(".AddNewJournalWidget",gw,env=.rqda)
-        assign(".AddNewJournalWidget2",gpanedgroup(horizontal = FALSE, con=get(".AddNewJournalWidget",env=.rqda)),env=.rqda)
-        gbutton("Save Journal",con=get(".AddNewJournalWidget2",env=.rqda),handler=function(h,...){
+        assign(".AddNewJournalWidget",gw,envir=.rqda)
+        assign(".AddNewJournalWidget2",gpanedgroup(horizontal = FALSE, container=get(".AddNewJournalWidget",envir=.rqda)),envir=.rqda)
+        gbutton("Save Journal",container=get(".AddNewJournalWidget2",envir=.rqda),handler=function(h,...){
             ## title <- ginput("Enter new file name. ",text=Sys.time(), icon="info")
             title <- as.character(Sys.time())
             if (!is.na(title)){
@@ -89,24 +91,24 @@ AddNewJournalFun <- function(){
                                                    enc(title), content, date(),.rqda$owner,1))
             if (is.null(ans)) {
                 dispose(.rqda$.AddNewJournalWidget)
-                ##gmessage("Succeed.",con=T)
+                ##gmessage("Succeed.",container=TRUE)
             }
             ## must put here rather than in AddJournalButton()
             JournalNamesUpdate()
         }}
                 )## end of save button
-        tmp <- gtext(container=get(".AddNewJournalWidget2",env=.rqda))
+        tmp <- gtext(container=get(".AddNewJournalWidget2",envir=.rqda))
         font <- pangoFontDescriptionFromString(.rqda$font)
         gtkWidgetModifyFont(tmp@widget@widget,font)
-        assign(".AddNewJournalWidgetW", tmp, env=.rqda)
-        textW <- get(".AddNewJournalWidgetW",env=.rqda)
+        assign(".AddNewJournalWidgetW", tmp, envir=.rqda)
+        textW <- get(".AddNewJournalWidgetW",envir=.rqda)
     }}
 
 ViewJournalWidget <- function(prefix="Journal",widget=.rqda$.JournalNamesWidget,dbTable="journal"){
-  if (is_projOpen(env=.rqda,"qdacon")) {
+  if (is_projOpen(envir=.rqda,"qdacon")) {
       Selected <- svalue(widget)
       if (length(Selected)==0){
-        gmessage("Select first.",icon="error",con=TRUE)
+        gmessage("Select first.",icon="error",container=TRUE)
       }
       else {
         tryCatch(eval(parse(text=sprintf("dispose(.rqda$.%smemo)",prefix))),error=function(e) {})
@@ -115,11 +117,11 @@ ViewJournalWidget <- function(prefix="Journal",widget=.rqda$.JournalNamesWidget,
                            )
         mainIcon <- system.file("icon", "mainIcon.png", package = "RQDA")
         gw@widget@widget$SetIconFromFile(mainIcon)
-        assign(sprintf(".%smemo",prefix),gw,env=.rqda)
+        assign(sprintf(".%smemo",prefix),gw,envir=.rqda)
         assign(sprintf(".%smemo2",prefix),
-               gpanedgroup(horizontal = FALSE, con=get(sprintf(".%smemo",prefix),env=.rqda)),
-               env=.rqda)
-        saveJournalButton <- gbutton("Save Journal",con=get(sprintf(".%smemo2",prefix),env=.rqda),handler=function(h,...){
+               gpanedgroup(horizontal = FALSE, container=get(sprintf(".%smemo",prefix),envir=.rqda)),
+               envir=.rqda)
+        saveJournalButton <- gbutton("Save Journal",container=get(sprintf(".%smemo2",prefix),envir=.rqda),handler=function(h,...){
             newcontent <- svalue(W)
             newcontent <- enc(newcontent,encoding="UTF-8") ## take care of double quote.
             Encoding(Selected) <- "UTF-8"
@@ -127,26 +129,26 @@ ViewJournalWidget <- function(prefix="Journal",widget=.rqda$.JournalNamesWidget,
             enabled(button$saveJournalB) <- FALSE
         }
                                      )## end of save button
-        assign("saveJournalB",saveJournalButton,env=button)
+        assign("saveJournalB",saveJournalButton,envir=button)
         enabled(saveJournalButton) <- FALSE
-        tmp <- gtext(container=get(sprintf(".%smemo2",prefix),env=.rqda))
+        tmp <- gtext(container=get(sprintf(".%smemo2",prefix),envir=.rqda))
         font <- pangoFontDescriptionFromString(.rqda$font)
         gtkWidgetModifyFont(tmp@widget@widget,font)## set the default fontsize
-        assign(sprintf(".%smemoW",prefix),tmp,env=.rqda)
+        assign(sprintf(".%smemoW",prefix),tmp,envir=.rqda)
         prvcontent <- dbGetQuery(.rqda$qdacon, sprintf("select journal from %s where name='%s'",dbTable,enc(Selected)))[1,1]
         if (is.na(prvcontent)) prvcontent <- ""
         Encoding(prvcontent) <- "UTF-8"
-        W <- get(sprintf(".%smemoW",prefix),env=.rqda)
+        W <- get(sprintf(".%smemoW",prefix),envir=.rqda)
         add(W,prvcontent,do.newline=FALSE)
         addHandlerKeystroke(tmp,handler=function(h,...){
             enabled(button$saveJournalB) <- TRUE
         })
-        addHandlerUnrealize(get(sprintf(".%smemo",prefix),env=.rqda),handler <- function(h,...){
-            withinWidget <- svalue(get(sprintf(".%smemoW",prefix),env=.rqda))
+        addHandlerUnrealize(get(sprintf(".%smemo",prefix),envir=.rqda),handler <- function(h,...){
+            withinWidget <- svalue(get(sprintf(".%smemoW",prefix),envir=.rqda))
             InRQDA <- dbGetQuery(.rqda$qdacon, sprintf("select journal from %s where name='%s'",dbTable, enc(Selected)))[1, 1]
             if (isTRUE(all.equal(withinWidget,InRQDA))) {
                 return(FALSE) } else {
-                    val <- gconfirm("The Journal has bee changed, Close anyway?",con=TRUE)
+                    val <- gconfirm("The Journal has bee changed, Close anyway?",container=TRUE)
                     return(!val)
                 }
         }
